@@ -14,9 +14,9 @@ from git import Diff, GitCommandError, InvalidGitRepositoryError, Remote
 from git import Repo as GitCLI
 from git.remote import PushInfoList
 
-from codegen.utils.github_utils.config.constants import CODEGEN_BOT_EMAIL, CODEGEN_BOT_NAME
-from codegen.utils.perf_utils import stopwatch
-from codegen.utils.time_utils import humanize_duration
+from graph_sitter.constants import CODEGEN_BOT_EMAIL, CODEGEN_BOT_NAME
+from graph_sitter.perf import stopwatch
+from graph_sitter.utils import humanize_duration
 
 from .schemas.config import BaseRepoConfig
 from .schemas.enums import CheckoutResult, FetchResult
